@@ -725,8 +725,8 @@ plot(maxFN, col=6, add=TRUE)
 par(mar=c(4,4,2,1))
 plot(x, col=1, xlim = c(min,max))
 plot(y, col=2, add=TRUE)
-legend('topright', expression(x, y), lty=c(1,1), col=c(1,2))
+legend('bottom', expression(x, y), lty=c(1,1), col=c(1,2))
 plot(minFN, col=4)
 plot(maxFN, col=6, add=TRUE)
-legend('topright', expression(min, max), lty=c(1,1), col=c(4,6))
+legend('bottom', expression(min, max), lty=c(1,1), col=c(4,6))
 
